"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const types_1 = require("../../types");
const token_math_1 = require("@melonproject/token-math");
// Radar relay has a different symbol for our MLN
exports.mlnToMlnt = (token) => token.replace(/^MLN$/, 'MLNT');
exports.getHttpUrl = (options) => {
    const base = options.pair.base.symbol;
    const quote = options.pair.quote.symbol;
    switch (options.network) {
        case types_1.Network.KOVAN: {
            const prefix = 'https://api.kovan.radarrelay.com';
            return `${prefix}/v2/markets/${exports.mlnToMlnt(base)}-${exports.mlnToMlnt(quote)}/book`;
        }
        case types_1.Network.MAINNET: {
            const prefix = 'https://api.radarrelay.com';
            return `${prefix}/v2/markets/${base}-${quote}/book`;
        }
        default:
            throw new Error('Invalid network.');
    }
};
exports.fetchRadarBook = (options) => {
    const url = exports.getHttpUrl(options);
    return axios_1.default.get(url).then(result => result.data);
};
exports.normalizeOrder = (options, order) => {
    const oid = Buffer.from(order.orderHash).toString('base64');
    const base = parseFloat(order.remainingBaseTokenAmount);
    const quote = parseFloat(order.remainingQuoteTokenAmount);
    const trade = token_math_1.createPrice(token_math_1.createQuantity(options.pair.base, base), token_math_1.createQuantity(options.pair.quote, quote));
    return {
        id: oid,
        exchange: types_1.Exchange.RADAR_RELAY,
        type: order.type,
        trade,
        original: order,
    };
};
